/// <reference types="node" />
import type { RawModuleRuleUse, RawModuleRule, RawModuleOptions } from "@rspack/binding";
import { ResolvedContext } from "./context";
import { ResolvedDevtool } from "./devtool";
export declare type Condition = string | RegExp;
export interface ModuleRule {
    name?: string;
    test?: Condition;
    include?: Condition | Condition[];
    exclude?: Condition | Condition[];
    resource?: Condition;
    resourceQuery?: Condition;
    use?: ModuleRuleUse[];
    type?: RawModuleRule["type"];
}
export interface Module {
    rules?: ModuleRule[];
    parser?: RawModuleOptions["parser"];
}
interface ResolvedModuleRule {
    test?: RawModuleRule["test"];
    include?: RawModuleRule["include"];
    exclude?: RawModuleRule["exclude"];
    resource?: RawModuleRule["resource"];
    resourceQuery?: RawModuleRule["resourceQuery"];
    use?: RawModuleRuleUse[];
    type?: RawModuleRule["type"];
}
export interface ResolvedModule {
    rules: ResolvedModuleRule[];
    parser?: RawModuleOptions["parser"];
}
interface LoaderContextInternal {
    source: number[];
    sourceMap: string | undefined | null;
    additionalData: AdditionalData | undefined | null;
    resource: string;
    resourcePath: string;
    resourceQuery: string | null;
    resourceFragment: string | null;
    cacheable: boolean;
}
export interface LoaderContext extends Pick<LoaderContextInternal, "resource" | "resourcePath" | "resourceQuery" | "resourceFragment"> {
    async(): (err: Error | null, content: string | Buffer, sourceMap?: string | SourceMap, additionalData?: AdditionalData) => void;
    callback(err: Error | null, content: string | Buffer, sourceMap?: string | SourceMap, additionalData?: AdditionalData): void;
    cacheable(cacheable: boolean): void;
    sourceMap: boolean;
    rootContext: string;
    context: string;
    getOptions: () => unknown;
}
export interface ComposeJsUseOptions {
    devtool: ResolvedDevtool;
    context: ResolvedContext;
}
export interface SourceMap {
    version: number;
    sources: string[];
    mappings: string;
    file?: string;
    sourceRoot?: string;
    sourcesContent?: string[];
    names?: string[];
}
export interface AdditionalData {
    [index: string]: any;
}
export interface LoaderResult {
    cacheable: boolean;
    content: string | Buffer;
    sourceMap?: string | SourceMap;
    additionalData?: AdditionalData;
}
export interface Loader {
    (this: LoaderContext, content: string | Buffer, sourceMap?: string | SourceMap, additionalData?: AdditionalData): void;
    displayName?: string;
    raw?: boolean;
}
declare type BuiltinLoader = string;
declare type ModuleRuleUse = {
    builtinLoader: BuiltinLoader;
    options?: unknown;
    name?: string;
} | {
    loader: Loader;
    options?: unknown;
    name?: string;
};
export declare function createRawModuleRuleUses(uses: ModuleRuleUse[], options: ComposeJsUseOptions): RawModuleRuleUse[];
export declare function resolveModuleOptions(module: Module, options: ComposeJsUseOptions): ResolvedModule;
export {};
//# sourceMappingURL=module.d.ts.map